@@ -7,11 +7,10 @@ describe 'designate' do
 
   let :params do
     {
-      :package_ensure        => 'installed',
-      :debug                 => 'False',
-      :purge_config          => false,
-      :neutron_endpoint_type => 'internalURL',
-      :root_helper           => 'sudo designate-rootwrap /etc/designate/rootwrap.conf'
+      :package_ensure     => 'installed',
+      :debug              => 'False',
+      :purge_config       => false,
+      :root_helper        => 'sudo designate-rootwrap /etc/designate/rootwrap.conf'
     }
   end
 
@@ -20,7 +19,8 @@ describe 'designate' do
       :rabbit_hosts        => [ '10.0.0.1:5672', '10.0.0.2:5672', '10.0.0.3:5672' ],
       :rabbit_userid       => 'guest',
       :rabbit_password     => '',
-      :rabbit_virtual_host => '/'
+      :rabbit_virtual_host => '/',
+      :amqp_durable_queues => true
     }
   end
 
@@ -135,10 +135,6 @@ describe 'designate' do
       is_expected.to contain_designate_config('DEFAULT/root_helper').with_value( params[:root_helper] )
     end
 
-    it 'configures network endpoint type to use' do
-      is_expected.to contain_designate_config('network_api:neutron/endpoint_type').with_value( params[:neutron_endpoint_type] )
-    end
-
     it 'configures notification' do
       is_expected.to contain_designate_config('oslo_messaging_notifications/driver').with_value('messaging' )
       is_expected.to contain_designate_config('oslo_messaging_notifications/topics').with_value('notifications')
@@ -164,6 +160,7 @@ describe 'designate' do
     it { is_expected.to contain_designate_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_designate_config('oslo_messaging_rabbit/rabbit_port').with_value( params[:rabbit_port] ) }
     it { is_expected.to contain_designate_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value( 'false' ) }
+    it { is_expected.to contain_designate_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
 
   end
 
@@ -181,6 +178,7 @@ describe 'designate' do
     it { is_expected.to contain_designate_config('oslo_messaging_rabbit/rabbit_hosts').with_value( '10.0.0.1:5672,10.0.0.2:5672,10.0.0.3:5672' ) }
     it { is_expected.to contain_designate_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_designate_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value( 'true' ) }
+    it { is_expected.to contain_designate_config('oslo_messaging_rabbit/amqp_durable_queues').with_value( 'true' ) }
 
   end
 
